package
module
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Jul 9, 2021
License: CC0-1.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
assertions
Package assertions provides simple helpers for writing Go tests.
Documentation
¶
-
type A
-
func (assert *A) Equal(have, want interface{}, msg string)
-
func (assert *A) Equalf(have, want interface{}, format string, a ...interface{})
-
func (assert *A) Lax(fn func(assert *A))
-
func (assert *A) NoError(err error, msg string)
-
func (assert *A) NoErrorf(err error, format string, a ...interface{})
-
func (assert *A) True(expr bool, msg string)
-
func (assert *A) Truef(expr bool, format string, a ...interface{})
-
type T
A is the test harness.
func New(t T) (assert *A)
func (assert *A) Equal(have, want interface{}, msg string)
func (assert *A) Equalf(have, want interface{}, format string, a ...interface{})
func (assert *A) Lax(fn func(assert *A))
func (assert *A) NoErrorf(err error, format string, a ...interface{})
func (assert *A) Truef(expr bool, format string, a ...interface{})
type T interface {
Helper()
Logf(format string, args ...interface{})
Fail()
FailNow()
Failed() bool
}
T is a subset of interface testing.TB.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.